---
title: key change-passphrase
eleventyNavigation:
  key: key change-passphrase
  parent: 🎬 Actions
---

{% include snippet/command-line/sample.md %}

```
{% include borgmatic/command-line/key-change-passphrase.txt %}
```
